pub enum InteractionMatrixRecipe {
RandomUniform {
minimum: f64,
maximum: f64,
rng: RngConfig,
},
RandomGaussian {
mean: f64,
standard_deviation: f64,
rng: RngConfig,
},
CorrelatedGaussian {
mean: f64,
standard_deviation: f64,
reciprocal_correlation: f64,
connectance: f64,
diagonal: DiagonalPolicy,
normalization: MatrixNormalization,
rng: RngConfig,
},
SignStructuredGaussian {
structure: SignStructure,
scale: f64,
connectance: f64,
diagonal: DiagonalPolicy,
normalization: MatrixNormalization,
rng: RngConfig,
},
}Expand description
Reproducible scientific instructions for an ecological matrix realization.
Variants
RandomUniform
Independently sample every matrix entry from a uniform distribution.
RandomGaussian
Independently sample every matrix entry from a Gaussian distribution.
Gaussian reciprocal pairs with Pearson correlation in [-1,1].
SignStructuredGaussian
Pairwise signs constrained to a common ecological relationship class.
Implementations
Sourceimpl InteractionMatrixRecipe
impl InteractionMatrixRecipe
pub fn validate(&self, species: usize) -> Result<(), InteractionRecipeError>
pub fn generate( &self, species: usize, ) -> Result<InteractionMatrix, InteractionRecipeError>
pub const fn rng(&self) -> RngConfig