pub struct TrajectoryObserver { /* private fields */ }Expand description
A bounded observer. Construct it with TrajectoryObserver::from_policy
so disabled observation allocates nothing.
Implementations
Sourceimpl TrajectoryObserver
impl TrajectoryObserver
Sourcepub fn from_policy(
policy: TrajectoryObservationPolicy,
) -> Result<Option<Self>, TrajectoryObserverError>
pub fn from_policy( policy: TrajectoryObservationPolicy, ) -> Result<Option<Self>, TrajectoryObserverError>
Returns None for Disabled, ensuring that mode has no observer or allocation.
pub const fn sample_interval_iterations(&self) -> u64
Sourcepub fn requires_equilibrium_evidence(&self, iteration: u64) -> bool
pub fn requires_equilibrium_evidence(&self, iteration: u64) -> bool
Lets a model avoid calculating a residual on observations that will not be retained.
pub fn observe( &mut self, observation: TrajectoryObservation<'_>, ) -> Result<Option<TerminationSignal>, TrajectoryObserverError>
Sourcepub fn finish(
self,
final_observation: TrajectoryObservation<'_>,
stop_reason: StopReason,
) -> Result<TerminalState, TrajectoryObserverError>
pub fn finish( self, final_observation: TrajectoryObservation<'_>, stop_reason: StopReason, ) -> Result<TerminalState, TrajectoryObserverError>
Completes the observer and always incorporates final_observation, even off cadence.